@@ -2,6 +2,7 @@
 """
 The standard Cartesian axes used for most ProPlot figures.
 """
+import copy
 import inspect
 
 import matplotlib.dates as mdates
@@ -11,14 +12,23 @@ import numpy as np
 from .. import constructor
 from .. import scale as pscale
 from .. import ticker as pticker
-from ..config import _parse_format, rc
+from ..config import rc
 from ..internals import ic  # noqa: F401
-from ..internals import _not_none, docstring, text, warnings
+from ..internals import _not_none, _pop_rc, dependencies, docstring, text, warnings
 from . import plot, shared
 
 __all__ = ['CartesianAxes']
 
 
+# Dictionary to reverse side keywords
+REVERSE_SIDE = {
+    'left': 'right',
+    'right': 'left',
+    'bottom': 'top',
+    'top': 'bottom',
+}
+
+
 # Format docstring
 _format_docstring = """
 aspect : {'auto', 'equal'} or float, optional
@@ -53,15 +63,25 @@ xscale, yscale : scale-spec, optional
 xscale_kw, yscale_kw : dict-like, optional
     The x and y axis scale settings. Passed to `~proplot.scale.Scale`.
 xloc, yloc : optional
-    Aliases for `xspineloc`, `yspineloc`.
-xspineloc, yspineloc \
-: {'both', 'bottom', 'top', 'left', 'right', 'neither', 'center', 'zero'}, optional
-    The x and y axis spine locations.
+    Shorthands for `xspineloc`, `yspineloc`.
+xspineloc, yspineloc : {'bottom', 'top', 'left', 'right', \
+'both', 'neither', 'none', 'zero', 'center'} or 2-tuple, optional
+    The x and y spine locations. Applied with `~matplotlib.spines.Spine.set_position`.
+    Propagates to `tickloc` unless specified otherwise.
 xtickloc, ytickloc \
-: {'both', 'bottom', 'top', 'left', 'right', 'neither'}, optional
-    Which x and y axis spines should have major and minor tick marks.
-xtickminor, ytickminor, tickminor : bool, optional
-    Whether to draw minor ticks on the x and y axes.
+: {'bottom', 'top', 'left', 'right', 'both', 'neither', 'none'}, optional
+    Which x and y axis spines should have major and minor tick marks. Inherits from
+    `spineloc` by default and propagates to `ticklabelloc` unless specified otherwise.
+xticklabelloc, yticklabelloc \
+: {'bottom', 'top', 'left', 'right', 'both', 'neither', 'none'}, optional
+    Which x and y axis spines should have major tick labels. Inherits from `tickloc`
+    by default and propagates to `labelloc` and `offsetloc` unless specified otherwise.
+xlabelloc, ylabelloc : {'bottom', 'top', 'left', 'right'}, optional
+    Which x and y axis spines should have axis labels. Inherits from
+    `ticklabelloc` by default (if `ticklabelloc` is a single side).
+xoffsetloc, yoffsetloc : {'left', 'right'}, optional
+    Which x and y axis spines should have the axis offset indicator. Inherits from
+    `ticklabelloc` by default (if `ticklabelloc` is a single side).
 xtickdir, ytickdir, tickdir : {'out', 'in', 'inout'}
     Direction that major and minor tick marks point for the x and y axis.
     Use `tickdir` to control both.
@@ -78,6 +98,9 @@ xgrid, ygrid, grid : bool, optional
 xgridminor, ygridminor, gridminor : bool, optional
     Whether to draw minor gridlines for the x and y axis.
     Use `gridminor` to toggle both.
+xtickminor, ytickminor, tickminor : bool, optional
+    Whether to draw minor ticks on the x and y axes.
+    Use `tickminor` to toggle both.
 xticks, yticks : optional
     Aliases for `xlocator`, `ylocator`.
 xlocator, ylocator : locator-spec, optional
@@ -162,10 +185,12 @@ _shared_docstring = """
 Parameters
 ----------
 %(extra)s**kwargs
-    Passed to `CartesianAxes`. You can optionally omit the {x}
-    from `CartesianAxes.format` keywords beginning with ``{x}``.
-    For example: ``ax.alt{x}(lim=(0, 10))`` is equivalent
-    to ``ax.alt{x}({x}lim=(0, 10))``.
+    Passed to `CartesianAxes`. Supports all valid  `~CartesianAxes.format` keywords.
+    You can optionally omit the {x} from keywords beginning with ``{x}`` -- for
+    example ``ax.alt{x}(lim=(0, 10))`` is equivalent to ``ax.alt{x}({x}lim=(0, 10))``.
+    You can also change the default side for the axis spine, axis tick marks, axis
+    tick labels, and/or axis labels by passing ``loc`` keywords. For example,
+    ``ax.alt{x}(loc='{x1}')`` changes the default side from {x2} to {x1}.
 
 Returns
 -------
@@ -222,10 +247,10 @@ _dual_extra = """
 funcscale : callable, 2-tuple of callables, or scale-spec
     The scale used to transform units from the parent axis to the secondary
     axis. This can be a `~proplot.scale.FuncScale` itself or a function,
-    (function, function) tuple, or an axis scale specification
-    interpreted by the `~proplot.constructor.Scale` constructor function,
-    any of which will be used to build a `~proplot.scale.FuncScale` and
-    applied to the dual axis (see `~proplot.scale.FuncScale` for details).
+    (function, function) tuple, or an axis scale specification interpreted
+    by the `~proplot.constructor.Scale` constructor function, any of which
+    will be used to build a `~proplot.scale.FuncScale` and applied
+    to the dual axis (see `~proplot.scale.FuncScale` for details).
 """
 _dual_docstring = _shared_docstring % {'descrip': _dual_descrip, 'extra': _dual_extra.lstrip()}  # noqa: E501
 docstring._snippet_manager['axes.dualx'] = _dual_docstring.format(**_shared_x_keys)
@@ -241,6 +266,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
     _name = 'cartesian'
     _name_aliases = ('cart', 'rect', 'rectilinar')  # include matplotlib name
 
+    @docstring._snippet_manager
     def __init__(self, *args, **kwargs):
         """
         Parameters
@@ -297,7 +323,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         # bottommost or to the *right* of the leftmost panel. But the sharing level
         # used for the leftmost and bottommost is the *figure* sharing level.
         axis = self.xaxis
-        if self._sharex is not None:
+        if self._sharex is not None and axis.get_visible():
             level = 3 if self._panel_sharex_group else self.figure._sharex
             if level > 0:
                 text._transfer_text(axis.label, self._sharex.xaxis.label)
@@ -308,7 +334,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
                 axis.set_tick_params(which='both', labelbottom=False, labeltop=False)
         # Y axis
         axis = self.yaxis
-        if self._sharey is not None:
+        if self._sharey is not None and axis.get_visible():
             level = 3 if self._panel_sharey_group else self.figure._sharey
             if level > 0:
                 text._transfer_text(axis.label, self._sharey.yaxis.label)
@@ -555,9 +581,15 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         # later so that labels set with set_xlabel() and set_ylabel() are shared too.
         # See notes in _align_axis_labels() and _apply_axis_sharing().
         kwargs = self._get_label_props(**kwargs)
-        if all(a is None for a in args) and all(v is None for v in kwargs.values()):
+        no_args = all(a is None for a in args)
+        no_kwargs = all(v is None for v in kwargs.values())
+        if no_args and no_kwargs:
             return  # also returns if args and kwargs are empty
-        getattr(self, 'set_' + x + 'label')(*args, **kwargs)
+        setter = getattr(self, 'set_' + x + 'label')
+        getter = getattr(self, 'get_' + x + 'label')
+        if no_args:  # otherwise label text is reset!
+            args = (getter(),)
+        setter(*args, **kwargs)
 
     def _update_locators(
         self, x, locator=None, minorlocator=None, *,
@@ -586,8 +618,8 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
             minorlocator = constructor.Locator(minorlocator, **minorlocator_kw)
         elif tickminor:
             minorlocator = getattr(axis._scale, '_default_minor_locator', None)
-            if not minorlocator:
-                minorlocator = constructor.Locator('minor')
+            minorlocator = copy.copy(minorlocator)
+            minorlocator = constructor.Locator(minorlocator or 'minor')
         if minorlocator is not None:
             axis.set_minor_locator(minorlocator)
             axis.isDefault_minloc = isdefault
@@ -695,24 +727,42 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
             if bounds is not None:
                 spine.set_bounds(*bounds)
 
-    def _update_locs(self, x, *, tickloc=None, ticklabelloc=None, labelloc=None):
+    def _update_locs(
+        self, x, *, tickloc=None, ticklabelloc=None, labelloc=None, offsetloc=None
+    ):
         """
         Update the tick, tick label, and axis label locations.
         """
         # The tick and tick label sides for Cartesian axes
         kw = {}
         sides = ('bottom', 'top') if x == 'x' else ('left', 'right')
+        sides_map = {'both': sides, 'neither': (), 'none': (), None: None}
         sides_active = tuple(side for side in sides if self.spines[side].get_visible())
-        sides_dict = {None: None, 'both': sides, 'none': (), 'neither': ()}
 
         # The tick side(s)
-        ticklocs = sides_dict.get(tickloc, (tickloc,))
+        # NOTE: Silently forbids adding ticks to sides with invisible spines
+        ticklocs = sides_map.get(tickloc, (tickloc,))
+        if ticklocs and any(loc not in sides for loc in ticklocs):
+            raise ValueError(
+                f'Invalid tick mark location {tickloc!r}. Options are '
+                + ', '.join(map(repr, sides + tuple(sides_map))) + '.'
+            )
         if ticklocs is not None:
             kw.update({side: side in ticklocs for side in sides})
-        kw.update({side: False for side in sides if side not in sides_active})
+        kw.update(
+            {
+                side: False for side in sides if side not in sides_active
+            }
+        )
 
         # The tick label side(s). Make sure these only appear where ticks are
-        ticklabellocs = sides_dict.get(ticklabelloc, (ticklabelloc,))
+        # NOTE: Silently forbids adding labels to sides with invisible ticks or spines
+        ticklabellocs = sides_map.get(ticklabelloc, (ticklabelloc,))
+        if ticklabellocs and any(loc not in sides for loc in ticklabellocs):
+            raise ValueError(
+                f'Invalid tick label location {ticklabelloc!r}. Options are '
+                + ', '.join(map(repr, sides + tuple(sides_map))) + '.'
+            )
         if ticklabellocs is not None:
             kw.update({'label' + side: (side in ticklabellocs) for side in sides})
         kw.update(
@@ -724,11 +774,12 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         )
 
         # The axis label side(s)
-        if labelloc is None:
-            if ticklocs is not None:
-                options = tuple(_ for _ in sides if _ in ticklocs and _ in sides_active)
-                if len(options) == 1:
-                    labelloc = options[0]
+        # NOTE: Silently forbids adding labels and offsets to sides with missing spines
+        if ticklocs is not None:
+            options = tuple(_ for _ in sides if _ in ticklocs and _ in sides_active)
+            if len(options) == 1:
+                labelloc = _not_none(labelloc, options[0])
+                offsetloc = _not_none(offsetloc, options[0])
         if labelloc is not None and labelloc not in sides:
             raise ValueError(
                 f'Invalid label location {labelloc!r}. Options are '
@@ -736,9 +787,18 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
             )
 
         # Apply the tick, tick label, and label locations
+        # Uses ugly mpl 3.3+ tick_top() tick_bottom() kludge for offset location
+        # See: https://matplotlib.org/3.3.1/users/whats_new.html
+        axis = getattr(self, x + 'axis')
         self.tick_params(axis=x, which='both', **kw)
         if labelloc is not None:
-            getattr(self, x + 'axis').set_label_position(labelloc)
+            axis.set_label_position(labelloc)
+        if offsetloc is not None:
+            if hasattr(axis, 'set_offset_position'):  # y axis (and future x axis?)
+                axis.set_offset_position(offsetloc)
+            elif x == 'x' and dependencies._version_mpl >= 3.3:  # ugly mpl kludge
+                axis._tick_position = offsetloc
+                axis.offsetText.set_verticalalignment(REVERSE_SIDE[offsetloc])
 
     @docstring._snippet_manager
     def format(
@@ -748,6 +808,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         xspineloc=None, yspineloc=None,
         xtickloc=None, ytickloc=None, fixticks=False,
         xlabelloc=None, ylabelloc=None,
+        xoffsetloc=None, yoffsetloc=None,
         xticklabelloc=None, yticklabelloc=None,
         xtickdir=None, ytickdir=None,
         xgrid=None, ygrid=None,
@@ -776,6 +837,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         xticklen=None, yticklen=None,
         xlinewidth=None, ylinewidth=None,
         xcolor=None, ycolor=None, color=None,  # special case (see below)
+        xlabelcolor=None, ylabelcolor=None,
         xgridcolor=None, ygridcolor=None,
         xlabel_kw=None, ylabel_kw=None,
         xscale_kw=None, yscale_kw=None,
@@ -812,7 +874,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         or `datetime.datetime` array as the x or y axis coordinate, the axis ticks
         and tick labels will be automatically formatted as dates.
         """
-        rc_kw, rc_mode, kwargs = _parse_format(**kwargs)
+        rc_kw, rc_mode = _pop_rc(kwargs)
         with rc.context(rc_kw, mode=rc_mode):
             # No mutable default args
             xlabel_kw = xlabel_kw or {}
@@ -831,6 +893,8 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
             # we apply 'color' right here.
             xcolor = _not_none(xcolor, color)
             ycolor = _not_none(ycolor, color)
+            xlabelcolor = _not_none(xlabelcolor, xcolor)
+            ylabelcolor = _not_none(ylabelcolor, ycolor)
 
             # Flexible keyword args, declare defaults
             xtickdir = _not_none(xtickdir, rc.find('xtick.direction', context=True))
@@ -849,30 +913,35 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
             # want this sometimes! Same goes for spines!
             xspineloc = _not_none(xloc=xloc, xspineloc=xspineloc)
             yspineloc = _not_none(yloc=yloc, yspineloc=yspineloc)
-            xtickloc = _not_none(xtickloc, xspineloc, self._get_loc('x', 'xtick'))
-            ytickloc = _not_none(ytickloc, yspineloc, self._get_loc('y', 'ytick'))
-            xspineloc = _not_none(xspineloc, self._get_loc('x', 'axes.spines'))
-            yspineloc = _not_none(yspineloc, self._get_loc('y', 'axes.spines'))
-            if xtickloc != 'both':
+            if isinstance(xspineloc, str) and xspineloc not in ('zero', 'center'):
+                xtickloc = _not_none(xtickloc, xspineloc)
+            if isinstance(yspineloc, str) and yspineloc not in ('zero', 'center'):
+                ytickloc = _not_none(ytickloc, yspineloc)
+            if xtickloc != 'both':  # then infer others
                 xticklabelloc = _not_none(xticklabelloc, xtickloc)
-                xlabelloc = _not_none(xlabelloc, xticklabelloc)
-                if xlabelloc not in (None, 'bottom', 'top'):  # e.g. "both"
-                    xlabelloc = 'bottom'
-            if ytickloc != 'both':
+                if xticklabelloc in ('bottom', 'top'):
+                    xlabelloc = _not_none(xlabelloc, xticklabelloc)
+                    xoffsetloc = _not_none(xoffsetloc, yticklabelloc)
+            if ytickloc != 'both':  # then infer others
                 yticklabelloc = _not_none(yticklabelloc, ytickloc)
-                ylabelloc = _not_none(ylabelloc, yticklabelloc)
-                if ylabelloc not in (None, 'left', 'right'):
-                    ylabelloc = 'left'
+                if yticklabelloc in ('left', 'right'):
+                    ylabelloc = _not_none(ylabelloc, yticklabelloc)
+                    yoffsetloc = _not_none(yoffsetloc, yticklabelloc)
+            xtickloc = _not_none(xtickloc, self._get_loc('x', 'xtick'))  # rc
+            ytickloc = _not_none(ytickloc, self._get_loc('y', 'ytick'))  # rc
+            xspineloc = _not_none(xspineloc, self._get_loc('x', 'axes.spines'))  # rc
+            yspineloc = _not_none(yspineloc, self._get_loc('y', 'axes.spines'))  # rc
 
             # Loop over axes
             for (
                 x, label,
                 labelpad, ticklabelpad,
-                color, gridcolor,
+                color, gridcolor, labelcolor,
                 ticklen, linewidth,
                 margin, bounds,
                 tickloc, spineloc,
                 ticklabelloc, labelloc,
+                offsetloc,
                 grid, gridminor,
                 tickminor, minorlocator,
                 min_, max_, lim,
@@ -887,11 +956,12 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
             ) in zip(
                 ('x', 'y'), (xlabel, ylabel),
                 (xlabelpad, ylabelpad), (xticklabelpad, yticklabelpad),
-                (xcolor, ycolor), (xgridcolor, ygridcolor),
+                (xcolor, ycolor), (xgridcolor, ygridcolor), (xlabelcolor, ylabelcolor),
                 (xticklen, yticklen), (xlinewidth, ylinewidth),
                 (xmargin, ymargin), (xbounds, ybounds),
                 (xtickloc, ytickloc), (xspineloc, yspineloc),
                 (xticklabelloc, yticklabelloc), (xlabelloc, ylabelloc),
+                (xoffsetloc, yoffsetloc),
                 (xgrid, ygrid), (xgridminor, ygridminor),
                 (xtickminor, ytickminor), (xminorlocator, yminorlocator),
                 (xmin, ymin), (xmax, ymax), (xlim, ylim),
@@ -930,7 +1000,8 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
 
                 # Axis tick settings
                 self._update_locs(
-                    x, tickloc=tickloc, ticklabelloc=ticklabelloc, labelloc=labelloc
+                    x, tickloc=tickloc, ticklabelloc=ticklabelloc,
+                    labelloc=labelloc, offsetloc=offsetloc,
                 )
                 self._update_rotation(
                     x, rotation=rotation
@@ -946,7 +1017,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
                 # NOTE: This must come after set_label_position, or ha or va overrides
                 # in label_kw are overwritten.
                 self._update_labels(
-                    x, label, color=color, labelpad=labelpad, **label_kw
+                    x, label, color=labelcolor, labelpad=labelpad, **label_kw
                 )
 
                 # Axis locator
@@ -977,18 +1048,16 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
             self.set_aspect(aspect)
         super().format(rc_kw=rc_kw, rc_mode=rc_mode, **kwargs)
 
-    def _parse_alt(self, kwargs, x):
+    def _parse_alt(self, x, **kwargs):
         """
         Optionally omit the leading x or y from "twin axes" methods.
         """
-        keys = tuple(
-            key[1:] for key in self._format_signature.parameters if key[0] == x
-        )
-        kw = {
-            (x + key if key in keys else key): val for key, val in kwargs.items()
-        }
-        ic(kw)
-        return kw
+        keys = tuple(k[1:] for k in self._format_signature.parameters if k[0] == x)
+        kwargs = {(x + k if k in keys else k): v for k, v in kwargs.items()}
+        for axis in 'xy':  # standardize format() location aliases
+            if axis + 'spineloc' in kwargs:
+                kwargs[axis + 'loc'] = kwargs.pop(axis + 'spineloc')
+        return kwargs
 
     @docstring._snippet_manager
     def altx(self, **kwargs):
@@ -1003,32 +1072,24 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         # To restore matplotlib behavior, which draws "child" artists on top simply
         # because the axes was created after the "parent" one, use the inset_axes
         # zorder of 4 and make the background transparent.
-        kwargs = self._parse_alt(kwargs, 'x')
+        kwargs = self._parse_alt('x', **kwargs)
+        kwargs.setdefault('yloc', 'neither')
+        kwargs.setdefault('xloc', 'top')  # other locations follow by default
+        kwargs.setdefault('grid', False)  # note xgrid=True would override this
+        kwargs.setdefault('zorder', 4)
+        kwargs.setdefault('autoscaley_on', self.get_autoscaley_on())
+
+        # Initialize twin axes
         ax = self._make_twin_axes(
             sharey=self, number=False, autoshare=False, projection='cartesian', **kwargs
         )
-
-        # Child defaults
-        # NOTE: This is not completely ideal since e.g. users passing labelloc
-        # will get overwritten. But mostly not a huge deal.
         ax._altx_parent = self
-        for side, spine in ax.spines.items():
-            spine.set_visible(side == 'top')
-        ax.xaxis.tick_top()
-        ax.xaxis.set_label_position('top')
-        ax.yaxis.set_visible(False)
         ax.patch.set_visible(False)
-        ax.grid(False)
-        ax.set_zorder(4)
-        ax.set_autoscaley_on(self.get_autoscaley_on())
+        ax.yaxis.set_visible(False)
 
         # Parent defaults
-        self.spines['top'].set_visible(False)
-        self.spines['bottom'].set_visible(True)
-        self.xaxis.tick_bottom()
-        self.xaxis.set_label_position('bottom')
-
-        # Add axes
+        kwformat = {'xloc': REVERSE_SIDE.get(kwargs['xloc'], None)}
+        self.format(**kwformat)
         self.add_child_axes(ax)  # to facilitate tight layout
         self.figure._axstack.remove(ax)  # or gets drawn twice!
 
@@ -1039,31 +1100,25 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         """
         %(axes.alty)s
         """
-        # Initialize axes
-        kwargs = self._parse_alt(kwargs, 'y')
+        # Parse input args
+        kwargs = self._parse_alt('y', **kwargs)
+        kwargs.setdefault('xloc', 'neither')
+        kwargs.setdefault('yloc', 'right')  # other locations follow by default
+        kwargs.setdefault('grid', False)  # note ygrid=True would override this
+        kwargs.setdefault('zorder', 4)
+        kwargs.setdefault('autoscalex_on', self.get_autoscalex_on())
+
+        # Initialize twin axes
         ax = self._make_twin_axes(
             sharex=self, number=False, autoshare=False, projection='cartesian', **kwargs
         )
-
-        # Child defaults
         ax._alty_parent = self
-        for side, spine in ax.spines.items():
-            spine.set_visible(side == 'right')
-        ax.yaxis.tick_right()
-        ax.yaxis.set_label_position('right')
-        ax.xaxis.set_visible(False)
         ax.patch.set_visible(False)
-        ax.grid(False)
-        ax.set_zorder(4)
-        ax.set_autoscalex_on(self.get_autoscalex_on())
+        ax.xaxis.set_visible(False)
 
-        # Parent defaults
-        self.spines['right'].set_visible(False)
-        self.spines['left'].set_visible(True)
-        self.yaxis.tick_left()
-        self.yaxis.set_label_position('left')
-
-        # Add axes
+        # Update parent axes
+        kwformat = {'yloc': REVERSE_SIDE.get(kwargs['yloc'], None)}
+        self.format(**kwformat)
         self.add_child_axes(ax)  # to facilitate tight layout
         self.figure._axstack.remove(ax)  # or gets drawn twice!
 
