@@ -16,7 +16,7 @@ import re
 import sys
 from collections import namedtuple
 from collections.abc import MutableMapping
-from numbers import Integral, Real
+from numbers import Real
 
 import cycler
 import matplotlib as mpl
@@ -28,7 +28,7 @@ import numpy as np
 from matplotlib import RcParams
 
 from .internals import ic  # noqa: F401
-from .internals import _not_none, docstring, rcsetup, warnings
+from .internals import _not_none, _translate_grid, docstring, rcsetup, warnings
 
 try:
     from IPython import get_ipython
@@ -377,126 +377,6 @@ def _iter_data_objects(folder, *args, **kwargs):
             raise FileNotFoundError(f'Invalid file path {path!r}.')
 
 
-@warnings._rename_kwargs('0.6', mode='rc_mode')
-def _parse_format(rc_kw=None, rc_mode=None, **kwargs):
-    """
-    Separate `rc` setting names from the keyword arguments for use in
-    a `~Config.context` block. Used by the various ``format`` functions.
-    """
-    # NOTE: rc_mode == 2 applies only the updated params. A power user
-    # could use ax.format(rc_mode=0) to re-apply all the current settings
-    kw = rc_kw or {}
-    mode = _not_none(rc_mode, 2)  # only apply updated params by default
-    for key, value in tuple(kwargs.items()):
-        name = rcsetup._rc_nodots.get(key, None)
-        if name in ('alpha', 'facecolor', 'edgecolor', 'linewidth'):
-            name = None  # former renamed settings
-        if name is not None:
-            kw[name] = kwargs.pop(key)
-    return kw, mode, kwargs
-
-
-def _translate_loc(loc, mode, *, default=None, **kwargs):
-    """
-    Translate the location string `loc` into a standardized form. The `mode`
-    must be a string for which there is a :rcraw:`mode.loc` setting. Additional
-    options can be added with keyword arguments.
-    """
-    # Create specific options dictionary
-    # NOTE: This is not inside validators.py because it is also used to
-    # validate various user-input locations.
-    if mode == 'panel':
-        loc_dict = rcsetup.PANEL_LOCS
-    elif mode == 'legend':
-        loc_dict = rcsetup.LEGEND_LOCS
-    elif mode == 'colorbar':
-        loc_dict = rcsetup.COLORBAR_LOCS
-    elif mode == 'text':
-        loc_dict = rcsetup.TEXT_LOCS
-    else:
-        raise ValueError(f'Invalid mode {mode!r}.')
-    loc_dict = loc_dict.copy()
-    loc_dict.update(kwargs)
-
-    # Translate location
-    if loc in (None, True):
-        loc = default
-    elif isinstance(loc, (str, Integral)):
-        try:
-            loc = loc_dict[loc]
-        except KeyError:
-            raise KeyError(
-                f'Invalid {mode} location {loc!r}. Options are: '
-                + ', '.join(map(repr, loc_dict))
-                + '.'
-            )
-    elif (
-        mode == 'legend'
-        and np.iterable(loc)
-        and len(loc) == 2
-        and all(isinstance(l, Real) for l in loc)
-    ):
-        loc = tuple(loc)
-    else:
-        raise KeyError(f'Invalid {mode} location {loc!r}.')
-
-    # Kludge / white lie
-    # TODO: Implement 'best' colorbar location
-    if mode == 'colorbar' and loc == 'best':
-        loc = 'lower right'
-
-    return loc
-
-
-def _translate_gridline_toggle(b, key):
-    """
-    Translate an instruction to turn either major or minor gridlines on or off into a
-    boolean and string applied to :rcraw:`axes.grid` and :rcraw:`axes.grid.which`.
-    """
-    ob = rc_matplotlib['axes.grid']
-    owhich = rc_matplotlib['axes.grid.which']
-
-    # Instruction is to turn off gridlines
-    if not b:
-        # Gridlines are already off, or they are on for the particular
-        # ones that we want to turn off. Instruct to turn both off.
-        if (
-            not ob
-            or key == 'grid' and owhich == 'major'
-            or key == 'gridminor' and owhich == 'minor'
-        ):
-            which = 'both'  # disable both sides
-        # Gridlines are currently on for major and minor ticks, so we
-        # instruct to turn on gridlines for the one we *don't* want off
-        elif owhich == 'both':  # and ob is True, as already tested
-            # if gridminor=False, enable major, and vice versa
-            b = True
-            which = 'major' if key == 'gridminor' else 'minor'
-        # Gridlines are on for the ones that we *didn't* instruct to
-        # turn off, and off for the ones we do want to turn off. This
-        # just re-asserts the ones that are already on.
-        else:
-            b = True
-            which = owhich
-
-    # Instruction is to turn on gridlines
-    else:
-        # Gridlines are already both on, or they are off only for the
-        # ones that we want to turn on. Turn on gridlines for both.
-        if (
-            owhich == 'both'
-            or key == 'grid' and owhich == 'minor'
-            or key == 'gridminor' and owhich == 'major'
-        ):
-            which = 'both'
-        # Gridlines are off for both, or off for the ones that we
-        # don't want to turn on. We can just turn on these ones.
-        else:
-            which = owhich
-
-    return b, which
-
-
 def config_inline_backend(fmt=None):
     """
     Set up the ipython `inline backend display format \
@@ -861,7 +741,7 @@ class Configurator(MutableMapping, dict):
 
     def __getitem__(self, key):
         """
-        Return a setting from `rc_matplotlib` or `rc_proplot`.
+        Return an `rc_matplotlib` or `rc_proplot` setting.
         """
         key = self._validate_key(key)  # might issue proplot removed/renamed error
         try:
@@ -872,7 +752,7 @@ class Configurator(MutableMapping, dict):
 
     def __setitem__(self, key, value):
         """
-        Modify an `rc_matplotlib` setting or an `rc_proplot` setting.
+        Modify an `rc_matplotlib` or `rc_proplot` setting.
         """
         kw_proplot, kw_matplotlib = self._get_params(key, value)
         rc_proplot.update(kw_proplot)
@@ -880,7 +760,7 @@ class Configurator(MutableMapping, dict):
 
     def __getattr__(self, attr):
         """
-        Return a setting from `rc_matplotlib` or `rc_proplot`.
+        Return an `rc_matplotlib` or `rc_proplot` setting.
         """
         if attr[:1] == '_':
             return super().__getattribute__(attr)  # raise built-in error
@@ -889,7 +769,7 @@ class Configurator(MutableMapping, dict):
 
     def __setattr__(self, attr, value):
         """
-        Modify an `rc_matplotlib` setting or an `rc_proplot` setting.
+        Modify an `rc_matplotlib` or `rc_proplot` setting.
         """
         if attr[:1] == '_':
             super().__setattr__(attr, value)
@@ -1111,7 +991,7 @@ class Configurator(MutableMapping, dict):
 
         # Gridline toggling
         elif contains('grid', 'gridminor'):
-            b, which = _translate_gridline_toggle(
+            b, which = _translate_grid(
                 value, 'gridminor' if contains('gridminor') else 'grid'
             )
             kw_matplotlib['axes.grid'] = b
@@ -1151,6 +1031,11 @@ class Configurator(MutableMapping, dict):
         """
         Return locations of local proplotrc files in this directory
         and in parent directories.
+
+        See also
+        --------
+        Configurator.user_file
+        Configurator.user_folder
         """
         cdir = os.getcwd()
         paths = []
@@ -1193,19 +1078,23 @@ class Configurator(MutableMapping, dict):
         location ``~/.proplotrc`` or ``~/.proplot/proplotrc`` is always returned if the
         file exists, regardless of the operating system. If multiple valid locations
         are found, a warning is raised.
+
+        See also
+        --------
+        Configurator.user_folder
+        Configurator.local_files
         """
         # Support both loose files and files inside .proplot
         file = os.path.join(Configurator.user_folder(), 'proplotrc')
         universal = os.path.join(os.path.expanduser('~'), '.proplotrc')
-        if os.path.isfile(universal) and os.path.isfile(file):
-            warnings._warn_proplot(
-                'Found conflicting default user proplotrc files at '
-                f'{universal!r} and {file!r}. Ignoring the second one.'
-            )
         if os.path.isfile(universal):
-            return universal
-        else:
-            return file
+            if file != universal and os.path.isfile(file):
+                warnings._warn_proplot(
+                    'Found conflicting default user proplotrc files at '
+                    f'{universal!r} and {file!r}. Ignoring the second one.'
+                )
+            file = universal
+        return file
 
     @staticmethod
     def user_folder(subfolder=None):
@@ -1216,6 +1105,11 @@ class Configurator(MutableMapping, dict):
         is unset. On other operating systems, this is ``~/.proplot``. The location
         ``~/.proplot`` is always returned if the folder exists, regardless of the
         operating system. If multiple valid locations are found, a warning is raised.
+
+        See also
+        --------
+        Configurator.user_file
+        Configurator.local_files
         """
         # Try the XDG standard location
         # NOTE: This is borrowed from matplotlib.get_configdir
@@ -1228,7 +1122,7 @@ class Configurator(MutableMapping, dict):
         # Fallback to the loose ~/.proplot if it is present
         # NOTE: This is critical or we might ignore previously stored settings!
         if os.path.isdir(universal):
-            if universal != folder and os.path.isdir(folder):
+            if folder != universal and os.path.isdir(folder):
                 warnings._warn_proplot(
                     'Found conflicting default user proplot folders at '
                     f'{universal!r} and {folder!r}. Ignoring the second one.'
@@ -1246,7 +1140,7 @@ class Configurator(MutableMapping, dict):
         Parameters
         ----------
         *args
-            Dictionaries of `rc` names and values.
+            Dictionaries of `rc` keys and values.
         file : path-like, optional
             Filename from which settings should be loaded.
         **kwargs
