@@ -18,11 +18,13 @@ import numpy as np
 from . import axes as paxes
 from . import constructor
 from . import gridspec as pgridspec
-from .config import _parse_format, _translate_loc, rc, rc_matplotlib
+from .config import rc, rc_matplotlib
 from .internals import ic  # noqa: F401
 from .internals import (
     _not_none,
     _pop_params,
+    _pop_rc,
+    _translate_loc,
     context,
     dependencies,
     docstring,
@@ -125,16 +127,6 @@ tight : bool, optional
     layout spacing. For example, with ``left=1``, the left margin is set to
     1 em-width, while the remaining margin widths are calculated automatically.
 %(gridspec.tight)s
-includepanels : bool, optional
-    Whether to include panels when aligning figure "super titles" along the top
-    of the subplot grid and when aligning the `spanx` *x* axis labels and `spany`
-    *y* axis labels along the sides of the subplot grid. Default is ``False``.
-mathtext_fallback : bool or str, optional
-    Apply this :rc:`mathtext.fallback` value when drawing the figure. If
-    ``True`` or string, unavailable glyphs are replaced with a glyph from a
-    fallback font (Computer Modern by default). Otherwise, they are replaced
-    with the "¤" dummy character. For details see this `mathtext tutorial \
-<https://matplotlib.org/stable/tutorials/text/mathtext.html#custom-fonts>`__.
 journal : str, optional
     String corresponding to an academic journal standard used to control the figure
     width `figwidth` and, if specified, the figure height `figheight`. See the below
@@ -497,6 +489,7 @@ class Figure(mfigure.Figure):
 
     # NOTE: If _rename_kwargs argument is an invalid identifier, it is
     # simply used in the warning message.
+    @docstring._obfuscate_kwargs
     @docstring._snippet_manager
     @warnings._rename_kwargs('0.7', axpad='innerpad', autoformat='pplt.rc.autoformat = {}')  # noqa: E501
     def __init__(
@@ -507,9 +500,9 @@ class Figure(mfigure.Figure):
         spanx=None, spany=None, span=None,
         alignx=None, aligny=None, align=None,
         left=None, right=None, top=None, bottom=None,
-        wspace=None, hspace=None, space=None, wpad=None, hpad=None, pad=None,
-        outerpad=None, innerpad=None, panelpad=None, includepanels=None,
-        tight=None, mathtext_fallback=None,
+        wspace=None, hspace=None, space=None,
+        tight=None, outerpad=None, innerpad=None, panelpad=None,
+        wpad=None, hpad=None, pad=None,
         **kwargs
     ):
         """
@@ -650,7 +643,6 @@ class Figure(mfigure.Figure):
         except KeyError:
             pass
         self._autospace = _not_none(tight, rc['subplots.tight'])
-        self._includepanels = _not_none(includepanels, False)
 
         # Translate share settings
         translate = {'labels': 1, 'labs': 1, 'limits': 2, 'lims': 2, 'all': 4}
@@ -687,7 +679,9 @@ class Figure(mfigure.Figure):
         self._subplot_counter = 0  # avoid add_subplot() returning an existing subplot
         self._is_adjusting = False
         self._is_authorized = False
-        rc_kw, rc_mode, kwargs = _parse_format(**kwargs)
+        self._includepanels = None
+        self._mathtext_context = {}
+        rc_kw, rc_mode = _pop_rc(kwargs)
         kw_format = _pop_params(kwargs, self._format_signature)
         with self._context_authorized():
             super().__init__(**kwargs)
@@ -712,15 +706,6 @@ class Figure(mfigure.Figure):
         d['bottom'] = rc['bottomlabel.pad']
         d['top'] = rc['toplabel.pad']
 
-        # Text drawing behavior
-        if mathtext_fallback is None:
-            context = {}
-        elif dependencies._version_mpl >= 3.4:
-            context = {'mathtext.fallback': mathtext_fallback if isinstance(mathtext_fallback, str) else 'cm' if mathtext_fallback else None}  # noqa: E501
-        else:
-            context = {'mathtext.fallback_to_cm': bool(mathtext_fallback)}
-        self._mathtext_context = context
-
         # Format figure
         # NOTE: This ignores user-input rc_mode.
         self.format(rc_kw=rc_kw, rc_mode=1, skip_axes=True, **kw_format)
@@ -796,7 +781,7 @@ class Figure(mfigure.Figure):
         axs = [ax for ax in axs if ax.get_visible()]
         return axs
 
-    def _get_align_coord(self, side, axs):
+    def _get_align_coord(self, side, axs, includepanels=False):
         """
         Return the figure coordinate for centering spanning axis labels or super titles.
         """
@@ -807,7 +792,7 @@ class Figure(mfigure.Figure):
             raise RuntimeError('Axes must be subplots.')
         s = 'y' if side in ('left', 'right') else 'x'
         axs = [ax._panel_parent or ax for ax in axs]  # deflect to main axes
-        if self._includepanels:  # include panel short axes
+        if includepanels:  # include panel short axes?
             axs = [_ for ax in axs for _ in ax._iter_axes(panels=True, children=False)]
         ranges = np.array([ax._range_subplotspec(s) for ax in axs])
         min_, max_ = ranges[:, 0].min(), ranges[:, 1].max()
@@ -943,7 +928,7 @@ class Figure(mfigure.Figure):
             if ax in seen or pos not in ('bottom', 'left'):
                 continue  # already aligned or cannot align
             axs = ax._get_span_axes(pos, panels=False)  # returns panel or main axes
-            if len(axs) == 1 or any(getattr(ax, '_share' + x) for ax in axs):
+            if any(getattr(ax, '_share' + x) for ax in axs):
                 continue  # nothing to align or axes have parents
             seen.update(axs)
             if span or align:
@@ -986,7 +971,7 @@ class Figure(mfigure.Figure):
             return
         labs = tuple(t for t in self._suplabel_dict['top'].values() if t.get_text())
         pad = (self._suptitle_pad / 72) / self.get_size_inches()[1]
-        x = self._get_align_coord('top', axs)[0]
+        x, _ = self._get_align_coord('top', axs, includepanels=self._includepanels)
         y = self._get_offset_coord('top', axs, renderer, pad=pad, extra=labs)
         self._suptitle.set_ha('center')
         self._suptitle.set_va('bottom')
@@ -1007,7 +992,7 @@ class Figure(mfigure.Figure):
 
         # Get the central label and "super" label for parallel alignment.
         # Initialize the super label if one does not already exist.
-        c, ax = self._get_align_coord(side, axs)  # returns panel axes
+        c, ax = self._get_align_coord(side, axs, includepanels=self._includepanels)
         axis = getattr(ax, x + 'axis')  # use the central axis
         label = labs.get(ax, None)
         if label is None and not axis.label.get_text().strip():
@@ -1415,7 +1400,8 @@ class Figure(mfigure.Figure):
         rlabels=None, rightlabels=None, rightlabels_kw=None,
         blabels=None, bottomlabels=None, bottomlabels_kw=None,
         tlabels=None, toplabels=None, toplabels_kw=None,
-        rowlabels=None, collabels=None, **kwargs,  # aliases
+        rowlabels=None, collabels=None,  # aliases
+        includepanels=None, mathtext_fallback=None, **kwargs,
     ):
         """
         Modify figure-wide labels and call ``format`` for the
@@ -1453,12 +1439,22 @@ class Figure(mfigure.Figure):
         """
         # Initiate context block
         skip_axes = kwargs.pop('skip_axes', False)  # internal keyword arg
-        rc_kw, rc_mode, kwargs = _parse_format(**kwargs)
+        rc_kw, rc_mode = _pop_rc(kwargs)
         with rc.context(rc_kw, mode=rc_mode):
             # Update background patch
             kw = rc.fill({'facecolor': 'figure.facecolor'}, context=True)
             self.patch.update(kw)
 
+            # Update text drawing behavior
+            if includepanels is not None:
+                self._includepanels = includepanels
+            if mathtext_fallback is not None:
+                if dependencies._version_mpl >= 3.4:
+                    context = {'mathtext.fallback': mathtext_fallback if isinstance(mathtext_fallback, str) else 'cm' if mathtext_fallback else None}  # noqa: E501
+                else:
+                    context = {'mathtext.fallback_to_cm': bool(mathtext_fallback)}
+                self._mathtext_context = context
+
             # Update super title and label padding
             pad = rc.find('suptitle.pad', context=True)  # super title
             if pad is not None:
