@@ -3,6 +3,10 @@
 Internal utilities.
 """
 import inspect
+from numbers import Integral, Real
+
+import numpy as np
+from matplotlib import rcParams as rc_matplotlib
 
 from . import (  # noqa: F401
     benchmarks, context, data, dependencies, docstring, rcsetup, text, warnings
@@ -40,7 +44,7 @@ ALIAS_MAPS = {
         'linewidth': ('lw', 'linewidths', 'ew', 'edgewidth', 'edgewidths'),
         'zorder': ('z', 'zorders'),
     },
-    'collection': {  # NOTE: face color is ignored for line collections
+    'collection': {  # WARNING: face color ignored for line collections
         'alpha': ('a', 'alphas'),  # WARNING: collections and contours use singular!
         'colors': ('c', 'color'),
         'edgecolors': ('ec', 'edgecolor', 'mec', 'markeredgecolor', 'markeredgecolors'),
@@ -50,6 +54,7 @@ ALIAS_MAPS = {
         ),
         'linestyles': ('ls', 'linestyle'),
         'linewidths': ('lw', 'linewidth', 'ew', 'edgewidth', 'edgewidths', 'mew', 'markeredgewidth', 'markeredgewidths'),  # noqa: E501
+        'marker': ('m', 'markers'),
         'sizes': ('s', 'ms', 'markersize', 'markersizes'),
         'zorder': ('z', 'zorders'),
     },
@@ -62,7 +67,7 @@ ALIAS_MAPS = {
         'linestyle': ('ls', 'linestyles'),
         'linewidth': ('lw', 'linewidths'),
         'marker': ('m', 'markers'),
-        'markersize': ('s', 'ms', 'markersizes', 'sizes'),
+        'markersize': ('s', 'ms', 'markersizes'),  # WARNING: no 'sizes' here for barb
         'markeredgewidth': ('ew', 'edgewidth', 'edgewidths', 'mew', 'markeredgewidths'),
         'markeredgecolor': ('ec', 'edgecolor', 'edgecolors', 'mec', 'markeredgecolors'),
         'markerfacecolor': (
@@ -201,6 +206,21 @@ def _not_none(*args, default=None, **kwargs):
     return first
 
 
+def _pop_kwargs(kwargs, *keys, **aliases):
+    """
+    Pop the input properties and return them in a new dictionary.
+    """
+    output = {}
+    aliases.update({key: () for key in keys})
+    for key, aliases in aliases.items():
+        aliases = (aliases,) if isinstance(aliases, str) else aliases
+        opts = {key: kwargs.pop(key, None) for key in (key, *aliases)}
+        value = _not_none(**opts)
+        if value is not None:
+            output[key] = value
+    return output
+
+
 def _pop_params(kwargs, *funcs, ignore_internal=False):
     """
     Pop parameters of the input functions or methods.
@@ -231,69 +251,156 @@ def _pop_params(kwargs, *funcs, ignore_internal=False):
     return output
 
 
-def _translate_kwargs(input, output, *keys, **aliases):
+def _pop_props(input, *categories, prefix=None, ignore=None, skip=None):
     """
-    The driver function.
+    Pop the registered properties and return them in a new dictionary.
     """
-    aliases.update({key: () for key in keys})
-    for key, aliases in aliases.items():
-        aliases = (aliases,) if isinstance(aliases, str) else aliases
-        opts = {key: input.pop(key, None) for key in (key, *aliases)}
-        value = _not_none(**opts)
-        if value is not None:
-            output[key] = value
-    return output
-
-
-def _translate_props(input, output, *categories, prefix=None, ignore=None):  # noqa: E501
-    """
-    The driver function.
-    """
-    # Get properties
+    output = {}
+    skip = skip or ()
+    ignore = ignore or ()
+    if isinstance(skip, str):  # e.g. 'sizes' for barbs() input
+        skip = (skip,)
+    if isinstance(ignore, str):  # e.g. 'marker' to ignore marker properties
+        ignore = (ignore,)
     prefix = prefix or ''  # e.g. 'box' for boxlw, boxlinewidth, etc.
     for category in categories:
         for key, aliases in ALIAS_MAPS[category].items():
             if isinstance(aliases, str):
                 aliases = (aliases,)
-            opts = {prefix + alias: input.pop(prefix + alias, None) for alias in (key, *aliases)}  # noqa: E501
+            opts = {
+                prefix + alias: input.pop(prefix + alias, None)
+                for alias in (key, *aliases)
+                if alias not in skip
+            }
             prop = _not_none(**opts)
-            if prop is not None:
-                output[key] = prop
-    # Ignore properties (e.g., ignore 'marker' properties)
-    ignore = ignore or ()
-    if isinstance(ignore, str):
-        ignore = (ignore,)
-    for string in ignore:
-        for key in tuple(output):
-            if string in key:
-                value = output.pop(key)
-                warnings._warn_proplot(f'Ignoring property {key}={value!r}.')
+            if prop is None:
+                continue
+            if any(string in key for string in ignore):
+                warnings._warn_proplot(f'Ignoring property {key}={prop!r}.')
+                continue
+            output[key] = prop
     return output
 
 
-def _pop_kwargs(src, *keys, **aliases):
+def _pop_rc(src):
     """
-    Pop out input properties and return them in a new dictionary.
+    Pop the rc setting names and mode for a `~Configurator.context` block.
     """
-    return _translate_kwargs(src, {}, *keys, **aliases)
+    # NOTE: rc_mode == 2 applies only the updated params. A power user
+    # could use ax.format(rc_mode=0) to re-apply all the current settings
+    kw = src.pop('rc_kw', None) or {}
+    if 'mode' in src:
+        src['rc_mode'] = src.pop('mode')
+        warnings._warn_proplot(
+            "Keyword 'mode' was deprecated in v0.6. Please use 'rc_mode' instead."
+        )
+    mode = src.pop('rc_mode', None)
+    mode = _not_none(mode, 2)  # only apply updated params by default
+    for key, value in tuple(src.items()):
+        name = rcsetup._rc_nodots.get(key, None)
+        if name in ('alpha', 'facecolor', 'edgecolor', 'linewidth'):
+            name = None  # former renamed settings
+        if name is not None:
+            kw[name] = src.pop(key)
+    return kw, mode
 
 
-def _process_kwargs(src, *keys, **aliases):
+def _translate_loc(loc, mode, *, default=None, **kwargs):
     """
-    Translate input properties and add translated names to the original dictionary.
+    Translate the location string `loc` into a standardized form. The `mode`
+    must be a string for which there is a :rcraw:`mode.loc` setting. Additional
+    options can be added with keyword arguments.
     """
-    return _translate_kwargs(src, src, *keys, **aliases)
+    # Create specific options dictionary
+    # NOTE: This is not inside validators.py because it is also used to
+    # validate various user-input locations.
+    if mode == 'panel':
+        loc_dict = rcsetup.PANEL_LOCS
+    elif mode == 'legend':
+        loc_dict = rcsetup.LEGEND_LOCS
+    elif mode == 'colorbar':
+        loc_dict = rcsetup.COLORBAR_LOCS
+    elif mode == 'text':
+        loc_dict = rcsetup.TEXT_LOCS
+    else:
+        raise ValueError(f'Invalid mode {mode!r}.')
+    loc_dict = loc_dict.copy()
+    loc_dict.update(kwargs)
+
+    # Translate location
+    if loc in (None, True):
+        loc = default
+    elif isinstance(loc, (str, Integral)):
+        try:
+            loc = loc_dict[loc]
+        except KeyError:
+            raise KeyError(
+                f'Invalid {mode} location {loc!r}. Options are: '
+                + ', '.join(map(repr, loc_dict))
+                + '.'
+            )
+    elif (
+        mode == 'legend'
+        and np.iterable(loc)
+        and len(loc) == 2
+        and all(isinstance(l, Real) for l in loc)
+    ):
+        loc = tuple(loc)
+    else:
+        raise KeyError(f'Invalid {mode} location {loc!r}.')
+
+    # Kludge / white lie
+    # TODO: Implement 'best' colorbar location
+    if mode == 'colorbar' and loc == 'best':
+        loc = 'lower right'
+
+    return loc
 
 
-def _pop_props(src, *categories, **kwargs):
+def _translate_grid(b, key):
     """
-    Pop out registered properties and return them in a new dictionary.
+    Translate an instruction to turn either major or minor gridlines on or off into a
+    boolean and string applied to :rcraw:`axes.grid` and :rcraw:`axes.grid.which`.
     """
-    return _translate_props(src, {}, *categories, **kwargs)
+    ob = rc_matplotlib['axes.grid']
+    owhich = rc_matplotlib['axes.grid.which']
 
+    # Instruction is to turn off gridlines
+    if not b:
+        # Gridlines are already off, or they are on for the particular
+        # ones that we want to turn off. Instruct to turn both off.
+        if (
+            not ob
+            or key == 'grid' and owhich == 'major'
+            or key == 'gridminor' and owhich == 'minor'
+        ):
+            which = 'both'  # disable both sides
+        # Gridlines are currently on for major and minor ticks, so we
+        # instruct to turn on gridlines for the one we *don't* want off
+        elif owhich == 'both':  # and ob is True, as already tested
+            # if gridminor=False, enable major, and vice versa
+            b = True
+            which = 'major' if key == 'gridminor' else 'minor'
+        # Gridlines are on for the ones that we *didn't* instruct to
+        # turn off, and off for the ones we do want to turn off. This
+        # just re-asserts the ones that are already on.
+        else:
+            b = True
+            which = owhich
 
-def _process_props(src, *categories, **kwargs):
-    """
-    Translate registered properties and add translated names to the original dictionary.
-    """
-    return _translate_props(src, src, *categories, **kwargs)
+    # Instruction is to turn on gridlines
+    else:
+        # Gridlines are already both on, or they are off only for the
+        # ones that we want to turn on. Turn on gridlines for both.
+        if (
+            owhich == 'both'
+            or key == 'grid' and owhich == 'minor'
+            or key == 'gridminor' and owhich == 'major'
+        ):
+            which = 'both'
+        # Gridlines are off for both, or off for the ones that we
+        # don't want to turn on. We can just turn on these ones.
+        else:
+            which = owhich
+
+    return b, which
